package be.ac.ulb.code.wit.service;

import be.ac.ulb.code.wit.contacts.*;
import javax.jws.WebService;

@WebService
public interface ContactService {

	/**
	 * Create a contact with the specified email address
	 * @param email The email address of the contact
	 * @return The newly-created contact
	 */
	public abstract Contact createContact(String email);

	/**
	 * Retrieves the details for a contact with the specified email
	 * @param email The email address of the contact to be retrieved
	 * @return The contact corresponding to the specified email
	 */
	public abstract Contact getContact(String email)
			throws NoSuchContactException;

    /**
     * Change the email address of a contact
     * @param oldemail The address of the contact to be updated
     * @param newemail The new email address of the contact
     */
	public abstract void changeEmail(String oldEmail, String newEmail)
			throws NoSuchContactException;

	/**
	 * Remove the specified contact
	 * @param email The email address of the contact to be removed
	 */
	public abstract void removeContact(String email)
			throws NoSuchContactException;

	/**
	 * Retrieves all contacts in the contacts list
	 * @return the list of contacts in the contacts list
	 */
	public abstract Contact[] getContacts();
}
